# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: epics_event.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='epics_event.proto',
  package='EPICS',
  syntax='proto2',
  serialized_options=_b('\n&edu.stanford.slac.archiverappliance.PBB\nEPICSEvent'),
  serialized_pb=_b('\n\x11\x65pics_event.proto\x12\x05\x45PICS\"\'\n\nFieldValue\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0b\n\x03val\x18\x02 \x02(\t\"\xc2\x01\n\x0cScalarString\x12\x17\n\x0fsecondsintoyear\x18\x01 \x02(\r\x12\x0c\n\x04nano\x18\x02 \x02(\r\x12\x0b\n\x03val\x18\x03 \x02(\t\x12\x13\n\x08severity\x18\x04 \x01(\x05:\x01\x30\x12\x11\n\x06status\x18\x05 \x01(\x05:\x01\x30\x12\x13\n\x0brepeatcount\x18\x06 \x01(\r\x12&\n\x0b\x66ieldvalues\x18\x07 \x03(\x0b\x32\x11.EPICS.FieldValue\x12\x19\n\x11\x66ieldactualchange\x18\x08 \x01(\x08\"\xc0\x01\n\nScalarByte\x12\x17\n\x0fsecondsintoyear\x18\x01 \x02(\r\x12\x0c\n\x04nano\x18\x02 \x02(\r\x12\x0b\n\x03val\x18\x03 \x02(\x0c\x12\x13\n\x08severity\x18\x04 \x01(\x05:\x01\x30\x12\x11\n\x06status\x18\x05 \x01(\x05:\x01\x30\x12\x13\n\x0brepeatcount\x18\x06 \x01(\r\x12&\n\x0b\x66ieldvalues\x18\x07 \x03(\x0b\x32\x11.EPICS.FieldValue\x12\x19\n\x11\x66ieldactualchange\x18\x08 \x01(\x08\"\xc1\x01\n\x0bScalarShort\x12\x17\n\x0fsecondsintoyear\x18\x01 \x02(\r\x12\x0c\n\x04nano\x18\x02 \x02(\r\x12\x0b\n\x03val\x18\x03 \x02(\x11\x12\x13\n\x08severity\x18\x04 \x01(\x05:\x01\x30\x12\x11\n\x06status\x18\x05 \x01(\x05:\x01\x30\x12\x13\n\x0brepeatcount\x18\x06 \x01(\r\x12&\n\x0b\x66ieldvalues\x18\x07 \x03(\x0b\x32\x11.EPICS.FieldValue\x12\x19\n\x11\x66ieldactualchange\x18\x08 \x01(\x08\"\xbf\x01\n\tScalarInt\x12\x17\n\x0fsecondsintoyear\x18\x01 \x02(\r\x12\x0c\n\x04nano\x18\x02 \x02(\r\x12\x0b\n\x03val\x18\x03 \x02(\x0f\x12\x13\n\x08severity\x18\x04 \x01(\x05:\x01\x30\x12\x11\n\x06status\x18\x05 \x01(\x05:\x01\x30\x12\x13\n\x0brepeatcount\x18\x06 \x01(\r\x12&\n\x0b\x66ieldvalues\x18\x07 \x03(\x0b\x32\x11.EPICS.FieldValue\x12\x19\n\x11\x66ieldactualchange\x18\x08 \x01(\x08\"\xc0\x01\n\nScalarEnum\x12\x17\n\x0fsecondsintoyear\x18\x01 \x02(\r\x12\x0c\n\x04nano\x18\x02 \x02(\r\x12\x0b\n\x03val\x18\x03 \x02(\x11\x12\x13\n\x08severity\x18\x04 \x01(\x05:\x01\x30\x12\x11\n\x06status\x18\x05 \x01(\x05:\x01\x30\x12\x13\n\x0brepeatcount\x18\x06 \x01(\r\x12&\n\x0b\x66ieldvalues\x18\x07 \x03(\x0b\x32\x11.EPICS.FieldValue\x12\x19\n\x11\x66ieldactualchange\x18\x08 \x01(\x08\"\xc1\x01\n\x0bScalarFloat\x12\x17\n\x0fsecondsintoyear\x18\x01 \x02(\r\x12\x0c\n\x04nano\x18\x02 \x02(\r\x12\x0b\n\x03val\x18\x03 \x02(\x02\x12\x13\n\x08severity\x18\x04 \x01(\x05:\x01\x30\x12\x11\n\x06status\x18\x05 \x01(\x05:\x01\x30\x12\x13\n\x0brepeatcount\x18\x06 \x01(\r\x12&\n\x0b\x66ieldvalues\x18\x07 \x03(\x0b\x32\x11.EPICS.FieldValue\x12\x19\n\x11\x66ieldactualchange\x18\x08 \x01(\x08\"\xc2\x01\n\x0cScalarDouble\x12\x17\n\x0fsecondsintoyear\x18\x01 \x02(\r\x12\x0c\n\x04nano\x18\x02 \x02(\r\x12\x0b\n\x03val\x18\x03 \x02(\x01\x12\x13\n\x08severity\x18\x04 \x01(\x05:\x01\x30\x12\x11\n\x06status\x18\x05 \x01(\x05:\x01\x30\x12\x13\n\x0brepeatcount\x18\x06 \x01(\r\x12&\n\x0b\x66ieldvalues\x18\x07 \x03(\x0b\x32\x11.EPICS.FieldValue\x12\x19\n\x11\x66ieldactualchange\x18\x08 \x01(\x08\"\xc2\x01\n\x0cVectorString\x12\x17\n\x0fsecondsintoyear\x18\x01 \x02(\r\x12\x0c\n\x04nano\x18\x02 \x02(\r\x12\x0b\n\x03val\x18\x03 \x03(\t\x12\x13\n\x08severity\x18\x04 \x01(\x05:\x01\x30\x12\x11\n\x06status\x18\x05 \x01(\x05:\x01\x30\x12\x13\n\x0brepeatcount\x18\x06 \x01(\r\x12&\n\x0b\x66ieldvalues\x18\x07 \x03(\x0b\x32\x11.EPICS.FieldValue\x12\x19\n\x11\x66ieldactualchange\x18\x08 \x01(\x08\"\xc0\x01\n\nVectorChar\x12\x17\n\x0fsecondsintoyear\x18\x01 \x02(\r\x12\x0c\n\x04nano\x18\x02 \x02(\r\x12\x0b\n\x03val\x18\x03 \x02(\x0c\x12\x13\n\x08severity\x18\x04 \x01(\x05:\x01\x30\x12\x11\n\x06status\x18\x05 \x01(\x05:\x01\x30\x12\x13\n\x0brepeatcount\x18\x06 \x01(\r\x12&\n\x0b\x66ieldvalues\x18\x07 \x03(\x0b\x32\x11.EPICS.FieldValue\x12\x19\n\x11\x66ieldactualchange\x18\x08 \x01(\x08\"\xc5\x01\n\x0bVectorShort\x12\x17\n\x0fsecondsintoyear\x18\x01 \x02(\r\x12\x0c\n\x04nano\x18\x02 \x02(\r\x12\x0f\n\x03val\x18\x03 \x03(\x11\x42\x02\x10\x01\x12\x13\n\x08severity\x18\x04 \x01(\x05:\x01\x30\x12\x11\n\x06status\x18\x05 \x01(\x05:\x01\x30\x12\x13\n\x0brepeatcount\x18\x06 \x01(\r\x12&\n\x0b\x66ieldvalues\x18\x07 \x03(\x0b\x32\x11.EPICS.FieldValue\x12\x19\n\x11\x66ieldactualchange\x18\x08 \x01(\x08\"\xc3\x01\n\tVectorInt\x12\x17\n\x0fsecondsintoyear\x18\x01 \x02(\r\x12\x0c\n\x04nano\x18\x02 \x02(\r\x12\x0f\n\x03val\x18\x03 \x03(\x0f\x42\x02\x10\x01\x12\x13\n\x08severity\x18\x04 \x01(\x05:\x01\x30\x12\x11\n\x06status\x18\x05 \x01(\x05:\x01\x30\x12\x13\n\x0brepeatcount\x18\x06 \x01(\r\x12&\n\x0b\x66ieldvalues\x18\x07 \x03(\x0b\x32\x11.EPICS.FieldValue\x12\x19\n\x11\x66ieldactualchange\x18\x08 \x01(\x08\"\xc4\x01\n\nVectorEnum\x12\x17\n\x0fsecondsintoyear\x18\x01 \x02(\r\x12\x0c\n\x04nano\x18\x02 \x02(\r\x12\x0f\n\x03val\x18\x03 \x03(\x11\x42\x02\x10\x01\x12\x13\n\x08severity\x18\x04 \x01(\x05:\x01\x30\x12\x11\n\x06status\x18\x05 \x01(\x05:\x01\x30\x12\x13\n\x0brepeatcount\x18\x06 \x01(\r\x12&\n\x0b\x66ieldvalues\x18\x07 \x03(\x0b\x32\x11.EPICS.FieldValue\x12\x19\n\x11\x66ieldactualchange\x18\x08 \x01(\x08\"\xc5\x01\n\x0bVectorFloat\x12\x17\n\x0fsecondsintoyear\x18\x01 \x02(\r\x12\x0c\n\x04nano\x18\x02 \x02(\r\x12\x0f\n\x03val\x18\x03 \x03(\x02\x42\x02\x10\x01\x12\x13\n\x08severity\x18\x04 \x01(\x05:\x01\x30\x12\x11\n\x06status\x18\x05 \x01(\x05:\x01\x30\x12\x13\n\x0brepeatcount\x18\x06 \x01(\r\x12&\n\x0b\x66ieldvalues\x18\x07 \x03(\x0b\x32\x11.EPICS.FieldValue\x12\x19\n\x11\x66ieldactualchange\x18\x08 \x01(\x08\"\xc6\x01\n\x0cVectorDouble\x12\x17\n\x0fsecondsintoyear\x18\x01 \x02(\r\x12\x0c\n\x04nano\x18\x02 \x02(\r\x12\x0f\n\x03val\x18\x03 \x03(\x01\x42\x02\x10\x01\x12\x13\n\x08severity\x18\x04 \x01(\x05:\x01\x30\x12\x11\n\x06status\x18\x05 \x01(\x05:\x01\x30\x12\x13\n\x0brepeatcount\x18\x06 \x01(\r\x12&\n\x0b\x66ieldvalues\x18\x07 \x03(\x0b\x32\x11.EPICS.FieldValue\x12\x19\n\x11\x66ieldactualchange\x18\x08 \x01(\x08\"\xd5\x01\n\x0eV4GenericBytes\x12\x17\n\x0fsecondsintoyear\x18\x01 \x02(\r\x12\x0c\n\x04nano\x18\x02 \x02(\r\x12\x0b\n\x03val\x18\x03 \x02(\x0c\x12\x13\n\x08severity\x18\x04 \x01(\x05:\x01\x30\x12\x11\n\x06status\x18\x05 \x01(\x05:\x01\x30\x12\x13\n\x0brepeatcount\x18\x06 \x01(\r\x12&\n\x0b\x66ieldvalues\x18\x07 \x03(\x0b\x32\x11.EPICS.FieldValue\x12\x19\n\x11\x66ieldactualchange\x18\x08 \x01(\x08\x12\x0f\n\x07userTag\x18\t \x01(\r\"\xbb\x02\n\x0bPayloadInfo\x12 \n\x04type\x18\x01 \x02(\x0e\x32\x12.EPICS.PayloadType\x12\x0e\n\x06pvname\x18\x02 \x02(\t\x12\x0c\n\x04year\x18\x03 \x02(\x05\x12\x14\n\x0c\x65lementCount\x18\x04 \x01(\x05\x12\x10\n\x08unused00\x18\x05 \x01(\x01\x12\x10\n\x08unused01\x18\x06 \x01(\x01\x12\x10\n\x08unused02\x18\x07 \x01(\x01\x12\x10\n\x08unused03\x18\x08 \x01(\x01\x12\x10\n\x08unused04\x18\t \x01(\x01\x12\x10\n\x08unused05\x18\n \x01(\x01\x12\x10\n\x08unused06\x18\x0b \x01(\x01\x12\x10\n\x08unused07\x18\x0c \x01(\x01\x12\x10\n\x08unused08\x18\r \x01(\x01\x12\x10\n\x08unused09\x18\x0e \x01(\t\x12\"\n\x07headers\x18\x0f \x03(\x0b\x32\x11.EPICS.FieldValue*\xa9\x02\n\x0bPayloadType\x12\x11\n\rSCALAR_STRING\x10\x00\x12\x10\n\x0cSCALAR_SHORT\x10\x01\x12\x10\n\x0cSCALAR_FLOAT\x10\x02\x12\x0f\n\x0bSCALAR_ENUM\x10\x03\x12\x0f\n\x0bSCALAR_BYTE\x10\x04\x12\x0e\n\nSCALAR_INT\x10\x05\x12\x11\n\rSCALAR_DOUBLE\x10\x06\x12\x13\n\x0fWAVEFORM_STRING\x10\x07\x12\x12\n\x0eWAVEFORM_SHORT\x10\x08\x12\x12\n\x0eWAVEFORM_FLOAT\x10\t\x12\x11\n\rWAVEFORM_ENUM\x10\n\x12\x11\n\rWAVEFORM_BYTE\x10\x0b\x12\x10\n\x0cWAVEFORM_INT\x10\x0c\x12\x13\n\x0fWAVEFORM_DOUBLE\x10\r\x12\x14\n\x10V4_GENERIC_BYTES\x10\x0e\x42\x34\n&edu.stanford.slac.archiverappliance.PBB\nEPICSEvent')
)

_PAYLOADTYPE = _descriptor.EnumDescriptor(
  name='PayloadType',
  full_name='EPICS.PayloadType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SCALAR_STRING', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCALAR_SHORT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCALAR_FLOAT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCALAR_ENUM', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCALAR_BYTE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCALAR_INT', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCALAR_DOUBLE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WAVEFORM_STRING', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WAVEFORM_SHORT', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WAVEFORM_FLOAT', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WAVEFORM_ENUM', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WAVEFORM_BYTE', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WAVEFORM_INT', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WAVEFORM_DOUBLE', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='V4_GENERIC_BYTES', index=14, number=14,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3364,
  serialized_end=3661,
)
_sym_db.RegisterEnumDescriptor(_PAYLOADTYPE)

PayloadType = enum_type_wrapper.EnumTypeWrapper(_PAYLOADTYPE)
SCALAR_STRING = 0
SCALAR_SHORT = 1
SCALAR_FLOAT = 2
SCALAR_ENUM = 3
SCALAR_BYTE = 4
SCALAR_INT = 5
SCALAR_DOUBLE = 6
WAVEFORM_STRING = 7
WAVEFORM_SHORT = 8
WAVEFORM_FLOAT = 9
WAVEFORM_ENUM = 10
WAVEFORM_BYTE = 11
WAVEFORM_INT = 12
WAVEFORM_DOUBLE = 13
V4_GENERIC_BYTES = 14



_FIELDVALUE = _descriptor.Descriptor(
  name='FieldValue',
  full_name='EPICS.FieldValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='EPICS.FieldValue.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='val', full_name='EPICS.FieldValue.val', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28,
  serialized_end=67,
)


_SCALARSTRING = _descriptor.Descriptor(
  name='ScalarString',
  full_name='EPICS.ScalarString',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='secondsintoyear', full_name='EPICS.ScalarString.secondsintoyear', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nano', full_name='EPICS.ScalarString.nano', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='val', full_name='EPICS.ScalarString.val', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='severity', full_name='EPICS.ScalarString.severity', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='EPICS.ScalarString.status', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeatcount', full_name='EPICS.ScalarString.repeatcount', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldvalues', full_name='EPICS.ScalarString.fieldvalues', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldactualchange', full_name='EPICS.ScalarString.fieldactualchange', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=264,
)


_SCALARBYTE = _descriptor.Descriptor(
  name='ScalarByte',
  full_name='EPICS.ScalarByte',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='secondsintoyear', full_name='EPICS.ScalarByte.secondsintoyear', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nano', full_name='EPICS.ScalarByte.nano', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='val', full_name='EPICS.ScalarByte.val', index=2,
      number=3, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='severity', full_name='EPICS.ScalarByte.severity', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='EPICS.ScalarByte.status', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeatcount', full_name='EPICS.ScalarByte.repeatcount', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldvalues', full_name='EPICS.ScalarByte.fieldvalues', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldactualchange', full_name='EPICS.ScalarByte.fieldactualchange', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=267,
  serialized_end=459,
)


_SCALARSHORT = _descriptor.Descriptor(
  name='ScalarShort',
  full_name='EPICS.ScalarShort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='secondsintoyear', full_name='EPICS.ScalarShort.secondsintoyear', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nano', full_name='EPICS.ScalarShort.nano', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='val', full_name='EPICS.ScalarShort.val', index=2,
      number=3, type=17, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='severity', full_name='EPICS.ScalarShort.severity', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='EPICS.ScalarShort.status', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeatcount', full_name='EPICS.ScalarShort.repeatcount', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldvalues', full_name='EPICS.ScalarShort.fieldvalues', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldactualchange', full_name='EPICS.ScalarShort.fieldactualchange', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=462,
  serialized_end=655,
)


_SCALARINT = _descriptor.Descriptor(
  name='ScalarInt',
  full_name='EPICS.ScalarInt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='secondsintoyear', full_name='EPICS.ScalarInt.secondsintoyear', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nano', full_name='EPICS.ScalarInt.nano', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='val', full_name='EPICS.ScalarInt.val', index=2,
      number=3, type=15, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='severity', full_name='EPICS.ScalarInt.severity', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='EPICS.ScalarInt.status', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeatcount', full_name='EPICS.ScalarInt.repeatcount', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldvalues', full_name='EPICS.ScalarInt.fieldvalues', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldactualchange', full_name='EPICS.ScalarInt.fieldactualchange', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=658,
  serialized_end=849,
)


_SCALARENUM = _descriptor.Descriptor(
  name='ScalarEnum',
  full_name='EPICS.ScalarEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='secondsintoyear', full_name='EPICS.ScalarEnum.secondsintoyear', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nano', full_name='EPICS.ScalarEnum.nano', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='val', full_name='EPICS.ScalarEnum.val', index=2,
      number=3, type=17, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='severity', full_name='EPICS.ScalarEnum.severity', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='EPICS.ScalarEnum.status', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeatcount', full_name='EPICS.ScalarEnum.repeatcount', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldvalues', full_name='EPICS.ScalarEnum.fieldvalues', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldactualchange', full_name='EPICS.ScalarEnum.fieldactualchange', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=852,
  serialized_end=1044,
)


_SCALARFLOAT = _descriptor.Descriptor(
  name='ScalarFloat',
  full_name='EPICS.ScalarFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='secondsintoyear', full_name='EPICS.ScalarFloat.secondsintoyear', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nano', full_name='EPICS.ScalarFloat.nano', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='val', full_name='EPICS.ScalarFloat.val', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='severity', full_name='EPICS.ScalarFloat.severity', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='EPICS.ScalarFloat.status', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeatcount', full_name='EPICS.ScalarFloat.repeatcount', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldvalues', full_name='EPICS.ScalarFloat.fieldvalues', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldactualchange', full_name='EPICS.ScalarFloat.fieldactualchange', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1047,
  serialized_end=1240,
)


_SCALARDOUBLE = _descriptor.Descriptor(
  name='ScalarDouble',
  full_name='EPICS.ScalarDouble',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='secondsintoyear', full_name='EPICS.ScalarDouble.secondsintoyear', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nano', full_name='EPICS.ScalarDouble.nano', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='val', full_name='EPICS.ScalarDouble.val', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='severity', full_name='EPICS.ScalarDouble.severity', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='EPICS.ScalarDouble.status', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeatcount', full_name='EPICS.ScalarDouble.repeatcount', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldvalues', full_name='EPICS.ScalarDouble.fieldvalues', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldactualchange', full_name='EPICS.ScalarDouble.fieldactualchange', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1243,
  serialized_end=1437,
)


_VECTORSTRING = _descriptor.Descriptor(
  name='VectorString',
  full_name='EPICS.VectorString',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='secondsintoyear', full_name='EPICS.VectorString.secondsintoyear', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nano', full_name='EPICS.VectorString.nano', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='val', full_name='EPICS.VectorString.val', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='severity', full_name='EPICS.VectorString.severity', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='EPICS.VectorString.status', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeatcount', full_name='EPICS.VectorString.repeatcount', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldvalues', full_name='EPICS.VectorString.fieldvalues', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldactualchange', full_name='EPICS.VectorString.fieldactualchange', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1440,
  serialized_end=1634,
)


_VECTORCHAR = _descriptor.Descriptor(
  name='VectorChar',
  full_name='EPICS.VectorChar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='secondsintoyear', full_name='EPICS.VectorChar.secondsintoyear', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nano', full_name='EPICS.VectorChar.nano', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='val', full_name='EPICS.VectorChar.val', index=2,
      number=3, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='severity', full_name='EPICS.VectorChar.severity', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='EPICS.VectorChar.status', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeatcount', full_name='EPICS.VectorChar.repeatcount', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldvalues', full_name='EPICS.VectorChar.fieldvalues', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldactualchange', full_name='EPICS.VectorChar.fieldactualchange', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1637,
  serialized_end=1829,
)


_VECTORSHORT = _descriptor.Descriptor(
  name='VectorShort',
  full_name='EPICS.VectorShort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='secondsintoyear', full_name='EPICS.VectorShort.secondsintoyear', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nano', full_name='EPICS.VectorShort.nano', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='val', full_name='EPICS.VectorShort.val', index=2,
      number=3, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='severity', full_name='EPICS.VectorShort.severity', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='EPICS.VectorShort.status', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeatcount', full_name='EPICS.VectorShort.repeatcount', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldvalues', full_name='EPICS.VectorShort.fieldvalues', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldactualchange', full_name='EPICS.VectorShort.fieldactualchange', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1832,
  serialized_end=2029,
)


_VECTORINT = _descriptor.Descriptor(
  name='VectorInt',
  full_name='EPICS.VectorInt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='secondsintoyear', full_name='EPICS.VectorInt.secondsintoyear', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nano', full_name='EPICS.VectorInt.nano', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='val', full_name='EPICS.VectorInt.val', index=2,
      number=3, type=15, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='severity', full_name='EPICS.VectorInt.severity', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='EPICS.VectorInt.status', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeatcount', full_name='EPICS.VectorInt.repeatcount', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldvalues', full_name='EPICS.VectorInt.fieldvalues', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldactualchange', full_name='EPICS.VectorInt.fieldactualchange', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2032,
  serialized_end=2227,
)


_VECTORENUM = _descriptor.Descriptor(
  name='VectorEnum',
  full_name='EPICS.VectorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='secondsintoyear', full_name='EPICS.VectorEnum.secondsintoyear', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nano', full_name='EPICS.VectorEnum.nano', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='val', full_name='EPICS.VectorEnum.val', index=2,
      number=3, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='severity', full_name='EPICS.VectorEnum.severity', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='EPICS.VectorEnum.status', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeatcount', full_name='EPICS.VectorEnum.repeatcount', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldvalues', full_name='EPICS.VectorEnum.fieldvalues', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldactualchange', full_name='EPICS.VectorEnum.fieldactualchange', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2230,
  serialized_end=2426,
)


_VECTORFLOAT = _descriptor.Descriptor(
  name='VectorFloat',
  full_name='EPICS.VectorFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='secondsintoyear', full_name='EPICS.VectorFloat.secondsintoyear', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nano', full_name='EPICS.VectorFloat.nano', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='val', full_name='EPICS.VectorFloat.val', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='severity', full_name='EPICS.VectorFloat.severity', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='EPICS.VectorFloat.status', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeatcount', full_name='EPICS.VectorFloat.repeatcount', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldvalues', full_name='EPICS.VectorFloat.fieldvalues', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldactualchange', full_name='EPICS.VectorFloat.fieldactualchange', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2429,
  serialized_end=2626,
)


_VECTORDOUBLE = _descriptor.Descriptor(
  name='VectorDouble',
  full_name='EPICS.VectorDouble',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='secondsintoyear', full_name='EPICS.VectorDouble.secondsintoyear', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nano', full_name='EPICS.VectorDouble.nano', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='val', full_name='EPICS.VectorDouble.val', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='severity', full_name='EPICS.VectorDouble.severity', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='EPICS.VectorDouble.status', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeatcount', full_name='EPICS.VectorDouble.repeatcount', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldvalues', full_name='EPICS.VectorDouble.fieldvalues', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldactualchange', full_name='EPICS.VectorDouble.fieldactualchange', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2629,
  serialized_end=2827,
)


_V4GENERICBYTES = _descriptor.Descriptor(
  name='V4GenericBytes',
  full_name='EPICS.V4GenericBytes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='secondsintoyear', full_name='EPICS.V4GenericBytes.secondsintoyear', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nano', full_name='EPICS.V4GenericBytes.nano', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='val', full_name='EPICS.V4GenericBytes.val', index=2,
      number=3, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='severity', full_name='EPICS.V4GenericBytes.severity', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='EPICS.V4GenericBytes.status', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeatcount', full_name='EPICS.V4GenericBytes.repeatcount', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldvalues', full_name='EPICS.V4GenericBytes.fieldvalues', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldactualchange', full_name='EPICS.V4GenericBytes.fieldactualchange', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userTag', full_name='EPICS.V4GenericBytes.userTag', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2830,
  serialized_end=3043,
)


_PAYLOADINFO = _descriptor.Descriptor(
  name='PayloadInfo',
  full_name='EPICS.PayloadInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='EPICS.PayloadInfo.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pvname', full_name='EPICS.PayloadInfo.pvname', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='year', full_name='EPICS.PayloadInfo.year', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='elementCount', full_name='EPICS.PayloadInfo.elementCount', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unused00', full_name='EPICS.PayloadInfo.unused00', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unused01', full_name='EPICS.PayloadInfo.unused01', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unused02', full_name='EPICS.PayloadInfo.unused02', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unused03', full_name='EPICS.PayloadInfo.unused03', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unused04', full_name='EPICS.PayloadInfo.unused04', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unused05', full_name='EPICS.PayloadInfo.unused05', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unused06', full_name='EPICS.PayloadInfo.unused06', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unused07', full_name='EPICS.PayloadInfo.unused07', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unused08', full_name='EPICS.PayloadInfo.unused08', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unused09', full_name='EPICS.PayloadInfo.unused09', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headers', full_name='EPICS.PayloadInfo.headers', index=14,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3046,
  serialized_end=3361,
)

_SCALARSTRING.fields_by_name['fieldvalues'].message_type = _FIELDVALUE
_SCALARBYTE.fields_by_name['fieldvalues'].message_type = _FIELDVALUE
_SCALARSHORT.fields_by_name['fieldvalues'].message_type = _FIELDVALUE
_SCALARINT.fields_by_name['fieldvalues'].message_type = _FIELDVALUE
_SCALARENUM.fields_by_name['fieldvalues'].message_type = _FIELDVALUE
_SCALARFLOAT.fields_by_name['fieldvalues'].message_type = _FIELDVALUE
_SCALARDOUBLE.fields_by_name['fieldvalues'].message_type = _FIELDVALUE
_VECTORSTRING.fields_by_name['fieldvalues'].message_type = _FIELDVALUE
_VECTORCHAR.fields_by_name['fieldvalues'].message_type = _FIELDVALUE
_VECTORSHORT.fields_by_name['fieldvalues'].message_type = _FIELDVALUE
_VECTORINT.fields_by_name['fieldvalues'].message_type = _FIELDVALUE
_VECTORENUM.fields_by_name['fieldvalues'].message_type = _FIELDVALUE
_VECTORFLOAT.fields_by_name['fieldvalues'].message_type = _FIELDVALUE
_VECTORDOUBLE.fields_by_name['fieldvalues'].message_type = _FIELDVALUE
_V4GENERICBYTES.fields_by_name['fieldvalues'].message_type = _FIELDVALUE
_PAYLOADINFO.fields_by_name['type'].enum_type = _PAYLOADTYPE
_PAYLOADINFO.fields_by_name['headers'].message_type = _FIELDVALUE
DESCRIPTOR.message_types_by_name['FieldValue'] = _FIELDVALUE
DESCRIPTOR.message_types_by_name['ScalarString'] = _SCALARSTRING
DESCRIPTOR.message_types_by_name['ScalarByte'] = _SCALARBYTE
DESCRIPTOR.message_types_by_name['ScalarShort'] = _SCALARSHORT
DESCRIPTOR.message_types_by_name['ScalarInt'] = _SCALARINT
DESCRIPTOR.message_types_by_name['ScalarEnum'] = _SCALARENUM
DESCRIPTOR.message_types_by_name['ScalarFloat'] = _SCALARFLOAT
DESCRIPTOR.message_types_by_name['ScalarDouble'] = _SCALARDOUBLE
DESCRIPTOR.message_types_by_name['VectorString'] = _VECTORSTRING
DESCRIPTOR.message_types_by_name['VectorChar'] = _VECTORCHAR
DESCRIPTOR.message_types_by_name['VectorShort'] = _VECTORSHORT
DESCRIPTOR.message_types_by_name['VectorInt'] = _VECTORINT
DESCRIPTOR.message_types_by_name['VectorEnum'] = _VECTORENUM
DESCRIPTOR.message_types_by_name['VectorFloat'] = _VECTORFLOAT
DESCRIPTOR.message_types_by_name['VectorDouble'] = _VECTORDOUBLE
DESCRIPTOR.message_types_by_name['V4GenericBytes'] = _V4GENERICBYTES
DESCRIPTOR.message_types_by_name['PayloadInfo'] = _PAYLOADINFO
DESCRIPTOR.enum_types_by_name['PayloadType'] = _PAYLOADTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FieldValue = _reflection.GeneratedProtocolMessageType('FieldValue', (_message.Message,), dict(
  DESCRIPTOR = _FIELDVALUE,
  __module__ = 'epics_event_pb2'
  # @@protoc_insertion_point(class_scope:EPICS.FieldValue)
  ))
_sym_db.RegisterMessage(FieldValue)

ScalarString = _reflection.GeneratedProtocolMessageType('ScalarString', (_message.Message,), dict(
  DESCRIPTOR = _SCALARSTRING,
  __module__ = 'epics_event_pb2'
  # @@protoc_insertion_point(class_scope:EPICS.ScalarString)
  ))
_sym_db.RegisterMessage(ScalarString)

ScalarByte = _reflection.GeneratedProtocolMessageType('ScalarByte', (_message.Message,), dict(
  DESCRIPTOR = _SCALARBYTE,
  __module__ = 'epics_event_pb2'
  # @@protoc_insertion_point(class_scope:EPICS.ScalarByte)
  ))
_sym_db.RegisterMessage(ScalarByte)

ScalarShort = _reflection.GeneratedProtocolMessageType('ScalarShort', (_message.Message,), dict(
  DESCRIPTOR = _SCALARSHORT,
  __module__ = 'epics_event_pb2'
  # @@protoc_insertion_point(class_scope:EPICS.ScalarShort)
  ))
_sym_db.RegisterMessage(ScalarShort)

ScalarInt = _reflection.GeneratedProtocolMessageType('ScalarInt', (_message.Message,), dict(
  DESCRIPTOR = _SCALARINT,
  __module__ = 'epics_event_pb2'
  # @@protoc_insertion_point(class_scope:EPICS.ScalarInt)
  ))
_sym_db.RegisterMessage(ScalarInt)

ScalarEnum = _reflection.GeneratedProtocolMessageType('ScalarEnum', (_message.Message,), dict(
  DESCRIPTOR = _SCALARENUM,
  __module__ = 'epics_event_pb2'
  # @@protoc_insertion_point(class_scope:EPICS.ScalarEnum)
  ))
_sym_db.RegisterMessage(ScalarEnum)

ScalarFloat = _reflection.GeneratedProtocolMessageType('ScalarFloat', (_message.Message,), dict(
  DESCRIPTOR = _SCALARFLOAT,
  __module__ = 'epics_event_pb2'
  # @@protoc_insertion_point(class_scope:EPICS.ScalarFloat)
  ))
_sym_db.RegisterMessage(ScalarFloat)

ScalarDouble = _reflection.GeneratedProtocolMessageType('ScalarDouble', (_message.Message,), dict(
  DESCRIPTOR = _SCALARDOUBLE,
  __module__ = 'epics_event_pb2'
  # @@protoc_insertion_point(class_scope:EPICS.ScalarDouble)
  ))
_sym_db.RegisterMessage(ScalarDouble)

VectorString = _reflection.GeneratedProtocolMessageType('VectorString', (_message.Message,), dict(
  DESCRIPTOR = _VECTORSTRING,
  __module__ = 'epics_event_pb2'
  # @@protoc_insertion_point(class_scope:EPICS.VectorString)
  ))
_sym_db.RegisterMessage(VectorString)

VectorChar = _reflection.GeneratedProtocolMessageType('VectorChar', (_message.Message,), dict(
  DESCRIPTOR = _VECTORCHAR,
  __module__ = 'epics_event_pb2'
  # @@protoc_insertion_point(class_scope:EPICS.VectorChar)
  ))
_sym_db.RegisterMessage(VectorChar)

VectorShort = _reflection.GeneratedProtocolMessageType('VectorShort', (_message.Message,), dict(
  DESCRIPTOR = _VECTORSHORT,
  __module__ = 'epics_event_pb2'
  # @@protoc_insertion_point(class_scope:EPICS.VectorShort)
  ))
_sym_db.RegisterMessage(VectorShort)

VectorInt = _reflection.GeneratedProtocolMessageType('VectorInt', (_message.Message,), dict(
  DESCRIPTOR = _VECTORINT,
  __module__ = 'epics_event_pb2'
  # @@protoc_insertion_point(class_scope:EPICS.VectorInt)
  ))
_sym_db.RegisterMessage(VectorInt)

VectorEnum = _reflection.GeneratedProtocolMessageType('VectorEnum', (_message.Message,), dict(
  DESCRIPTOR = _VECTORENUM,
  __module__ = 'epics_event_pb2'
  # @@protoc_insertion_point(class_scope:EPICS.VectorEnum)
  ))
_sym_db.RegisterMessage(VectorEnum)

VectorFloat = _reflection.GeneratedProtocolMessageType('VectorFloat', (_message.Message,), dict(
  DESCRIPTOR = _VECTORFLOAT,
  __module__ = 'epics_event_pb2'
  # @@protoc_insertion_point(class_scope:EPICS.VectorFloat)
  ))
_sym_db.RegisterMessage(VectorFloat)

VectorDouble = _reflection.GeneratedProtocolMessageType('VectorDouble', (_message.Message,), dict(
  DESCRIPTOR = _VECTORDOUBLE,
  __module__ = 'epics_event_pb2'
  # @@protoc_insertion_point(class_scope:EPICS.VectorDouble)
  ))
_sym_db.RegisterMessage(VectorDouble)

V4GenericBytes = _reflection.GeneratedProtocolMessageType('V4GenericBytes', (_message.Message,), dict(
  DESCRIPTOR = _V4GENERICBYTES,
  __module__ = 'epics_event_pb2'
  # @@protoc_insertion_point(class_scope:EPICS.V4GenericBytes)
  ))
_sym_db.RegisterMessage(V4GenericBytes)

PayloadInfo = _reflection.GeneratedProtocolMessageType('PayloadInfo', (_message.Message,), dict(
  DESCRIPTOR = _PAYLOADINFO,
  __module__ = 'epics_event_pb2'
  # @@protoc_insertion_point(class_scope:EPICS.PayloadInfo)
  ))
_sym_db.RegisterMessage(PayloadInfo)


DESCRIPTOR._options = None
_VECTORSHORT.fields_by_name['val']._options = None
_VECTORINT.fields_by_name['val']._options = None
_VECTORENUM.fields_by_name['val']._options = None
_VECTORFLOAT.fields_by_name['val']._options = None
_VECTORDOUBLE.fields_by_name['val']._options = None
# @@protoc_insertion_point(module_scope)
